@@ -30,6 +30,8 @@ import regex as re
 import spacy
 from sklearn.metrics import accuracy_score, precision_score, recall_score, f1_score
 
+package_level_resources_path = 'anonymizePy.resources.src'
+
 # ### Install nlp models AUTOMATE THIS PROCESS
 # !NOTE -- you must install this model: https://spacy.io/models/en#en_core_web_lg
 # - command to install model: python -m spacy download en_core_web_lg
@@ -138,7 +140,7 @@ class PIIGenerator:
         ]
 
         # Load optional name resources
-        self.resource_manager.load_resources('PIIPy.resources.src', ['firstnames_list.txt', 'lastnames_list.txt'], sorted=True)
+        self.resource_manager.load_resources(package_level_resources_path, ['firstnames_list.txt', 'lastnames_list.txt'], sorted=True)
 
         # If first_names was loaded, use it
         first_names = self.resource_manager.get_resources()[0]
@@ -527,7 +529,6 @@ class DataAnonymizer:
         print("Data loaded. Starting anonymization process.")
 
         # define resources path
-        package_level_resources_path = 'PIIPy.resources.src'
         txt_file_paths = self.resource_manager.get_txt_file_paths(package_level_resources_path)
 
         # load in resources
